# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.utils import timezone

class NeoAgent(models.Model):
    # A supervisor is an agent assigned to a zone
    # Assign an agent to an area, supervisors to a zone
    # Ensure an agent cannot have both area and zone set.
    first_name = models.CharField(max_length=30)
    last_name = models.CharField(max_length=30)
    date_created = models.DateTimeField(default=timezone.now, editable=False)

    class Meta:
        abstract = True

    def get_full_name(self):
        return '%s %s' % (self.first_name.title(), self.last_name.title())

class NeoPhoneNumber(models.Model):
    number = models.CharField(max_length=10, unique=True)

    class Meta:
        abstract = True

    def __str__(self):
        return '%s - %s' % (self.agent.get_full_name(), self.number)


# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='neo-agent',
    version='0.1.0',
    description='USSD session app for Django.',
    long_description=long_description,
    url='https://github.com/deone/neo-agent',
    author='Dayo Osikoya',
    author_email='alwaysdeone@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='ussd http session json response django',
    packages=find_packages(),
    install_requires=['Django'],
)